@@ -114,15 +114,14 @@ def find_features(seqs, locus_tag="all", utr_len=200):
 
     for seq_i in seqs:
         for feature in seq_i.features:
-            if feature.type == "CDS" and (locus_tag == "all" or \
-                    ('locus_tag' in feature.qualifiers and \
-                    feature.qualifiers['locus_tag'][0] == locus_tag)):
-                start = max(0, feature.location.nofuzzy_start - utr_len)
-                stop  = max(0, feature.location.nofuzzy_end + utr_len)
+            if feature.type == "CDS" and (locus_tag == "all" or
+                                          ('locus_tag' in feature.qualifiers and
+                                           feature.qualifiers['locus_tag'][0] == locus_tag)):
+                start = max(0, int(feature.location.start) - utr_len)
+                stop = max(0, int(feature.location.end) + utr_len)
                 feature_seq = seq_i.seq[start:stop]
-                f_match = FeatureMatch(feature, feature_seq, feature.strand,
+                f_match = FeatureMatch(feature, feature_seq, feature.location.strand,
                                        utr_len)
                 found_features.append(f_match)
 
     return found_features
-
